@@ -27,8 +27,11 @@ func NewCleanupJob(log zerolog.Logger, cacheRepo domain.FeedCacheRepo) *CleanupJ
 }
 
 func (j *CleanupJob) Run() {
+	j.log.Info().Msg("running feed-cache-cleanup job..")
+
 	if err := j.cacheRepo.DeleteStale(context.Background()); err != nil {
 		j.log.Error().Err(err).Msg("error when running feed cache cleanup job")
+		return
 	}
 
 	j.log.Info().Msg("successfully ran feed-cache-cleanup job")
