@@ -4,7 +4,6 @@
 package http
 
 import (
-	"context"
 	"fmt"
 	"net/http"
 	"runtime/debug"
@@ -33,55 +32,26 @@ func (s Server) IsAuthenticated(next http.Handler) http.Handler {
 			}
 		} else {
 			// check session
-			session, err := s.cookieStore.Get(r, "user_session")
-			if err != nil {
-				s.log.Error().Err(err).Msgf("could not get session from cookieStore")
-				session.Values["authenticated"] = false
-
-				// MaxAge<0 means delete cookie immediately
-				session.Options.MaxAge = -1
-				session.Options.Path = s.config.Config.BaseURL
-
-				if err := session.Save(r, w); err != nil {
-					s.log.Error().Err(err).Msgf("could not store session: %s", r.RemoteAddr)
-					http.Error(w, err.Error(), http.StatusInternalServerError)
-					return
+			authenticated := s.sessionManager.GetBool(r.Context(), "authenticated")
+			if !authenticated {
+				s.log.Debug().Msg("session not authenticated")
+				if err := s.sessionManager.Destroy(r.Context()); err != nil {
+					s.log.Error().Err(err).Msg("failed to destroy session")
 				}
-				http.Error(w, err.Error(), http.StatusForbidden)
-				return
-			}
-
-			// Check if user is authenticated
-			if auth, ok := session.Values["authenticated"].(bool); !ok || !auth {
-				s.log.Warn().Msg("session not authenticated")
-
 				http.Error(w, http.StatusText(http.StatusForbidden), http.StatusForbidden)
 				return
 			}
 
-			if created, ok := session.Values["created"].(int64); ok {
-				// created is a unix timestamp MaxAge is in seconds
-				maxAge := time.Duration(session.Options.MaxAge) * time.Second
-				expires := time.Unix(created, 0).Add(maxAge)
+			deadline := s.sessionManager.Deadline(r.Context())
+			if time.Until(deadline) <= 7*24*time.Hour {
+				s.log.Trace().Msgf("session is expiring in less than 7 days on %s - extending session", deadline.Format("2006-01-02 15:04:05"))
 
-				if time.Until(expires) <= 7*24*time.Hour { // 7 days
-					s.log.Info().Msgf("Cookie is expiring in less than 7 days on %s - extending session", expires.Format("2006-01-02 15:04:05"))
-
-					session.Values["created"] = time.Now().Unix()
-
-					// Call session.Save as needed - since it writes a header (the Set-Cookie
-					// header), making sure you call it before writing out a body is important.
-					// https://github.com/gorilla/sessions/issues/178#issuecomment-447674812
-					if err := session.Save(r, w); err != nil {
-						s.log.Error().Err(err).Msgf("could not store session: %s", r.RemoteAddr)
-						http.Error(w, err.Error(), http.StatusInternalServerError)
-						return
-					}
+				if err := s.sessionManager.RenewToken(r.Context()); err != nil {
+					s.log.Error().Err(err).Msgf("Auth: Failed to renew session token for username: [%s] ip: %s", s.sessionManager.GetString(r.Context(), "username"), r.RemoteAddr)
+					http.Error(w, http.StatusText(http.StatusInternalServerError), http.StatusInternalServerError)
+					return
 				}
 			}
-
-			ctx := context.WithValue(r.Context(), "session", session)
-			r = r.WithContext(ctx)
 		}
 
 		next.ServeHTTP(w, r)
